<?php

namespace App\Admin\Controllers;

use App\Models\Order;
use App\Admin\Actions\backstage\Orders\OrderDetails;
use Encore\Admin\Controllers\AdminController;
use Encore\Admin\Form;
use Encore\Admin\Grid;
use Encore\Admin\Show;

class BookingOrderController extends AdminController
{
    /**
     * Title for current resource.
     *
     * @var string
     */
    protected $title = '预约订单';

    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        $grid = new Grid(new Order());

        $grid->model()->wherein('product_type',[3,4,5]);

        //筛选

        $grid->filter(function ($filter){
            $filter->disableIdFilter();
            $filter->column(1/3, function ($filter) {
                $filter->like('user.nickname','用户姓名');
                $filter->like('docter.name','医生姓名');
                $filter->like('orderPatient.name','患者姓名');
            });
            $filter->column(1/3, function ($filter) {
                $filter->equal('user_id', '用户id');
                $filter->equal('docter_id', '医生id');
            });
            $filter->column(1/3,function ($filter) {
                $filter->equal('product_type','预约类型')->select(
                    [
                        3=>'门诊预约',
                        4=>'疫苗接种预约',
                        5=>'儿保预约'
                    ]
                );
                $filter->equal('order_status','订单状态')->radio(
                    [
                        ''=>'不限',
                        1=>'未支付',
                        2=>'待接单',
                        3=>'进行中',
                        4=>'已完成',
                        5=>'已取消'
                    ]
                );
            });
        });

        $grid->actions(function ($actions) {
            // 去掉删除
            $actions->disableDelete();
            // 去掉编辑
            $actions->disableEdit();
            // 去掉查看
            $actions->disableView();
            $actions->add(new OrderDetails());
        });

        $grid->column('id', __('Id'))->sortable();
        $grid->column('user_id', __('用户id'));
        $grid->column('user.nickname', __('用户姓名'));
        $grid->column('docter_id', __('医生id'));
        $grid->column('docter.name', __('医生姓名'));
        $grid->column('patient_id', __('患者id'));
        $grid->column('orderPatient.name', __('患者姓名'));
        $grid->column('orderPatient.symptoms', __('患者描述'));
        $grid->column('orderPatient.appoint_start_time', __('预约日期'))->display(function ($time){
            return date('Y-m-d H:i:s',$time);
        });
        $grid->column('orderPatient.appoint_end_time', __('就诊日期'))->display(function ($time){
            return date('Y-m-d H:i:s',$time);
        });
        $grid->column('product_type', __('产品类型'))->using([3=>'门诊预约',4=>'疫苗接种预约',5=>'儿保预约']);
        $grid->column('payment_type', __('支付方式'))->using([1=>'微信支付',2=>'余额支付']);
        $grid->column('order_status', __('订单状态'))->using([1=>'未支付',2=>'待接单',3=>'进行中',4=>'已完成',5=>'已取消']);
        $grid->column('payment_status', __('支付状态'))->using([1=>'待付款',2=>'已付款',3=>'退款中',4=>'已退款']);

        return $grid;
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     * @return Show
     */
    protected function detail($id)
    {
        $show = new Show(Order::findOrFail($id));

        $show->field('id', __('Id'));
        $show->field('user_id', __('User id'));
        $show->field('docter_id', __('Docter id'));
        $show->field('patient_id', __('Patient id'));
        $show->field('organization_id', __('Organization id'));
        $show->field('order_sn', __('Order sn'));
        $show->field('payment_type', __('Payment type'));
        $show->field('product_type', __('Product type'));
        $show->field('order_status', __('Order status'));
        $show->field('payment_status', __('Payment status'));
        $show->field('total_amount', __('Total amount'));
        $show->field('payment_amount', __('Payment amount'));
        $show->field('discount_amount', __('Discount amount'));
        $show->field('payment_time', __('Payment time'));
        $show->field('created_at', __('Created at'));
        $show->field('updated_at', __('Updated at'));
        $show->field('outtime', __('Outtime'));
        $show->field('receiving_time', __('Receiving time'));

        return $show;
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        $form = new Form(new Order());

        $form->number('user_id', __('User id'));
        $form->number('docter_id', __('Docter id'));
        $form->number('patient_id', __('Patient id'));
        $form->number('organization_id', __('Organization id'));
        $form->text('order_sn', __('Order sn'));
        $form->switch('payment_type', __('Payment type'))->default(1);
        $form->switch('product_type', __('Product type'))->default(1);
        $form->switch('order_status', __('Order status'))->default(1);
        $form->switch('payment_status', __('Payment status'))->default(1);
        $form->number('total_amount', __('Total amount'));
        $form->number('payment_amount', __('Payment amount'));
        $form->number('discount_amount', __('Discount amount'));
        $form->number('payment_time', __('Payment time'));
        $form->number('outtime', __('Outtime'));
        $form->number('receiving_time', __('Receiving time'));

        return $form;
    }
}
