<?php

namespace App\Admin\Controllers;

use App\Admin\Actions\backstage\User\archives;
use App\Admin\Actions\backstage\User\BalanceLog;
use App\Admin\Actions\backstage\User\BlackList;
use App\Admin\Actions\backstage\User\coupons;
use App\Models\Patient;
use App\Models\User;
use Encore\Admin\Controllers\AdminController;
use Encore\Admin\Form;
use Encore\Admin\Grid;
use Encore\Admin\Show;

class UserListController extends AdminController
{
    /**
     * Title for current resource.
     *
     * @var string
     */
    protected $title = '用户列表';

    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        $grid = new Grid(new User());
        $grid->actions(function ($actions) {
        // 去掉删除
        $actions->disableDelete();
        // 去掉编辑
        $actions->disableEdit();
        // 去掉查看
        $actions->disableView();
        $actions->add(new archives());
        $actions->add(new BalanceLog());
        $actions->add(new BlackList());
        $actions->add(new coupons());
    });
        //筛选
        $grid->filter(function ($filter){
            $filter->disableIdFilter();
            $filter->equal('phone','手机')->mobile()->placeholder("请输入手机");
            $filter->like('patient.name','患者姓名')->placeholder("请输入患者姓名");
            $filter->like('nickname','昵称');
            $filter->equal('status','用户状态')->radio([
                ''   => '不限',
                0    => '黑名单',
                1    => '正常',
            ]);
            $filter->equal('is_pack','用户状态')->radio([
                ''   => '全部用户',
                0    => '普通用户',
                1    => '服务包用户',
            ]);
        });
            $grid ->model()->where('status','>=','0');
            $grid->column('id', __('用户id'))->sortable();
            $grid->column('nickname', __('用户名'));
            $grid->column('sex', __('性别'))->using([0=>'未知',1=>'男',2=>'女']);
            $grid->column('age', __('年龄'));
            $grid->column('status', __('状态'))->using([0=>'黑名单',1=>'正常',]);
            $grid->column('is_pack', __('用户身份'))->using([0=>'普通用户',1=>'付费用户']);
            $grid->column('balance', __('当前余额'))->display(function ($price){
                return $price/100;
            });
            $grid->column('created_at', __('注册时间'));
            $grid->column('last_login_time', __('最后登录时间'))->display(function ($time){
                return date("Y-m-d H:i",$time);
            });
//            $grid->column('patient', __('患者姓名'))->pluck('name')->map('ucwords')->implode(',');
            $grid->column('patient', __('患者姓名'))->pluck('name')->label('default');
        return $grid;
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     * @return Show
     */
    protected function detail($id)
    {
        $show = new Show(User::findOrFail($id));
        return $show;
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        $form = new Form(new User());
        return $form;
    }
}
